# {py:mod}`lastuuid.dummies`

```{py:module} lastuuid.dummies
```

```{autodoc2-docstring} lastuuid.dummies
:parser: myst
:allowtitles:
```

## Module Contents

### Functions

````{list-table}
:class: autosummary longtable
:align: left

* - {py:obj}`uuidgen <lastuuid.dummies.uuidgen>`
  - ```{autodoc2-docstring} lastuuid.dummies.uuidgen
    :parser: myst
    :summary:
    ```
````

### API

````{py:function} uuidgen(i: int = 0, j: int = 0, k: int = 0, x: int = 0, y: int = 0) -> uuid.UUID
:canonical: lastuuid.dummies.uuidgen

```{autodoc2-docstring} lastuuid.dummies.uuidgen
:parser: myst
```
````
